Enum jdn_cli::CliError[][src]

pub enum CliError {
    InvalidNumberOfArguments {
        min: usize,
        max: Option<usize>,
        given: usize,
    },
    ArgumentParseFailure(String),
    ExecutionError(String),
}

An enumeration of errors that can occur while executing a CLI command.

Variants

InvalidNumberOfArguments

Indicates an invalid number of arguments was given to the handler.

Show fields

Fields of InvalidNumberOfArguments

min: usize

The minimum or only number of arguments expected.

max: Option<usize>

The maximum number of arguments expected.

given: usize

The number of arguments that was given to the handler.

ArgumentParseFailure(String)

Indicates an argument was unable to be coerced from a String. The internal attribute contains a description of the error that occurred.

ExecutionError(String)

Indicates an error occurred while executing the command. The internal attribute contains a description of the error that occurred.