An enumeration of errors that can occur while executing a CLI command.
Indicates an invalid number of arguments was given to the handler.
Show fields
Fields of InvalidNumberOfArguments
The minimum or only number of arguments expected.
The maximum number of arguments expected.
The number of arguments that was given to the handler.
Indicates an argument was unable to be coerced from a String.
The internal attribute contains a description of the error that occurred.
Indicates an error occurred while executing the command.
The internal attribute contains a description of the error that occurred.
Formats the value using the given formatter. Read more
Formats the value using the given formatter. Read more
The lower-level source of this error, if any. Read more
🔬 This is a nightly-only experimental API. (backtrace)
Returns a stack backtrace, if available, of where this error occurred. Read more
👎 Deprecated since 1.42.0:
use the Display impl or to_string()
👎 Deprecated since 1.33.0:
replaced by Error::source, which can support downcasting
impl<T> Any for T where
T: 'static + ?Sized, [src]
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>, [src]
Converts the given value to a String. Read more
impl<T, U> TryFrom<U> for T where
U: Into<T>, [src]
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.